#include <stdlib.h>
#include <libpq-fe.h>
void printResult(PGresult *result) {
  int i,j;
  int nrow = PQntuples(result);
  int ncols = PQnfields(result);
  for ( i=0; i < nrow; i++ ) {
    for ( j=0; j < ncols; j++)
      printf(“ %s - %s\n”, PQfname(result, j), PQgetvalue(result, i, j));
  }
  printf(“\n”);
}
void runSQL(PGconn *conn, char *sqlcomm) {
  PGresult *result;
  printf(“ %s \n”, sqlcomm);
  result = PQexec(conn, sqlcomm);
  printf(“\nStatus: %s\n”, PQresStatus(PQresultStatus(result)));
  printf(“Number of rows: %s\n”, PQcmdTuples(result));
  printf(“Result: %s\n”, PQresultErrorMessage(result));
  switch(PQresultStatus(result)) {
    case PGRES_TUPLES_OK: {
      printResult(result);    
      break;
    }
  }
}
int main(int argc, char** argv) {
  PGresult *result;
  PGconn *conn;
  int ntups;
  conn = PQconnectdb(“”);
  if(PQstatus(conn) == CONNECTION_OK) {
    printf(“Connection successful\n”);
    runSQL(conn, “BEGIN WORK”);
    runSQL(conn, “DECLARE sales_cursor CURSOR FOR SELECT * FROM sales”);
    do {
      result = PQexec(conn, “FETCH 12 IN sales_cursor”);
      if ( PQresultStatus(result) == PGRES_TUPLES_OK) {
        ntups = PQntuples(result);
        printResult(result);
        PQclear(result);
        printf(“Press Return to continue\n”);  
        getchar();
      } else ntups = 0;
    } while(ntups);
    runSQL(conn, “CLOSE sales_cursor”);
    runSQL(conn, “COMMIT WORK”);
  } else {
    printf(“Connection failed: %s\n”, PQerrorMessage(conn));
  }
  PQfinish(conn);
  return EXIT_SUCCESS;
}
