import psycopg2
from psycopg2 import Error
import matplotlib.pyplot as plt
import matplotlib.image as mpimg
import pandas as pd
import numpy as np
try:
  sqlstmt = "SELECT * FROM cal_housing"
  conn = psycopg2.connect(dbname="hanser", user="postgres", password="postgres", host="localhost")
  data = pd.read_sql_query(sqlstmt, conn)
  california_img=mpimg.imread('california.png')
  ax = data.plot(kind="scatter", x="longitude", y="latiude", figsize=(10,7),
                       s=data['population']/100, label="Population",
                       c="median_house_value", cmap=plt.get_cmap("jet"),
                       colorbar=False, alpha=0.4,
                      )
  plt.imshow(california_img, extent=[-124.55, -113.80, 32.45, 42.05], alpha=0.5)
  plt.ylabel("Latitude", fontsize=14)
  plt.xlabel("Longitude", fontsize=14)
  prices = data["median_house_value"]
  tick_values = np.linspace(prices.min(), prices.max(), 11)
  cbar = plt.colorbar()
  cbar.ax.set_yticklabels(["$%dk"%(round(v/1000)) for v in tick_values], fontsize=14)
  cbar.set_label('Median House Value', fontsize=16)
  plt.legend(fontsize=16)
  plt.show()
except (Exception, Error) as error:
  print("Fehler: ", error)
finally:
  conn.close()  
